@@ -36,7 +36,7 @@ use warnings 'once';
 
 use Carp;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use App::LXC::Container::Texts::en;
 
@@ -274,6 +274,9 @@ debug-level.
 BEGIN {				# uncoverable statement
     my $debugging_level = 0;
 
+    # FIXME: Delete diagnostics when error on some smokers is solved:
+    sub DL_diag() { return $debugging_level; }
+
     sub debug($;$@)
     {
 	my $level = shift;
